==> cloud-8.x-1.0.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Controller/Ec2/NetworkInterfaceAccessControlHandler.php <==
<?php

// Updated by yas 2016/05/25
// updated by yas 2016/05/20
// created by yas 2016/05/19.
namespace Drupal\aws_cloud\Controller\Ec2;

use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Access controller for the NetworkInterface entity.
 *
 * @see \Drupal\aws_cloud\Entity\Ec2\NetworkInterface\Entity\NetworkInterface.
 */
class NetworkInterfaceAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {

    switch ($operation) {
      case 'view':
        return AccessResult::allowedIfHasPermissions($account, ['view aws cloud network interface', 'view ' . $entity->getCloudContext()]);

      case 'update':
      case 'edit':
        return AccessResult::allowedIfHasPermissions($account, ['edit aws cloud network interface', 'view ' . $entity->getCloudContext()]);

      case 'delete':
        return AccessResult::allowedIfHasPermissions($account, ['delete aws cloud network interface', 'view ' . $entity->getCloudContext()]);
    }
    // Unknown operation, no opinion.
    return AccessResult::neutral();
  }

  /**
   * Not being used anymore.
   *
   * Access check is performed in \Drupal\cloud\Controller\CloudConfigController::access.
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'add aws cloud network interface');
  }

}

==> cloud-8.x-1.1-rc1.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Controller/Ec2/NetworkInterfaceAccessControlHandler.php <==
<?php

namespace Drupal\aws_cloud\Controller\Ec2;

use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Access controller for the NetworkInterface entity.
 *
 * @see \Drupal\aws_cloud\Entity\Ec2\NetworkInterface\Entity\NetworkInterface.
 */
class NetworkInterfaceAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {

    switch ($operation) {
      case 'view':
        return AccessResult::allowedIfHasPermissions($account, ['view aws cloud network interface', 'view ' . $entity->getCloudContext()]);

      case 'update':
      case 'edit':
        return AccessResult::allowedIfHasPermissions($account, ['edit aws cloud network interface', 'view ' . $entity->getCloudContext()]);

      case 'delete':
        return AccessResult::allowedIfHasPermissions($account, ['delete aws cloud network interface', 'view ' . $entity->getCloudContext()]);
    }
    // Unknown operation, no opinion.
    return AccessResult::neutral();
  }

  /**
   * Not being used anymore.
   *
   * Access check is performed in CloudConfigController::access.
   *
   * {@deprecated}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'add aws cloud network interface');
  }

}
